StepNodeStyle class

A class that defines the style for a step node in a step progress indicator.

The StepNodeStyle class allows customization of various aspects of the step node's appearance, including colors, shapes, icons, and animations.

The following properties can be customized:

  • defaultForegroundColor: The default color of the step node's foreground.
  • activeForegroundColor: The color of the step node's foreground when it is active.
  • animationDuration: The duration of the animation when the step node changes state.
  • shape: The shape of the step node.
  • decoration: The decoration of the step node. Defaults to a BoxDecoration with a semi-transparent white color.
  • activeDecoration: The decoration of the step node when it is active.
  • icon: The icon to display inside the step node.
  • activeIcon: The icon to display inside the step node when it is active. Defaults to a check icon.
  • iconColor: The color of the icon inside the step node.
  • activeIconColor: The color of the icon when the step node is active. Defaults to a highlighted teal color.
  • enableRippleEffect: Whether to enable the ripple effect on the step node. Defaults to true.
  • borderStyle: The style of the outer border for the step node.

Constructors

StepNodeStyle({Color? defaultForegroundColor, Color? activeForegroundColor, Duration? animationDuration, StepNodeShape? shape, BoxDecoration decoration = const BoxDecoration(color: Color.fromARGB(50, 255, 255, 255)), BoxDecoration? activeDecoration, Widget? icon, Widget? activeIcon = const Icon(Icons.check, size: 18, color: Colors.white), Color? iconColor, Color? activeIconColor, bool enableRippleEffect = true, OuterBorderStyle? borderStyle})
const

Properties

activeDecoration BoxDecoration?
The decoration of the step node when it is active.
final
activeForegroundColor Color?
The color for the foreground of the step node when it is active. If not set, it will be read from the theme.
final
activeIcon Widget?
The icon widget to display when the step is active.
final
activeIconColor Color?
The icon color when the step is active.
final
animationDuration Duration?
The duration of the animation for the step node. If not set, it will be read from the theme.
final
borderStyle OuterBorderStyle?
The style of the outer border for the step node.
final
decoration BoxDecoration
The decoration of the step node.
final
defaultForegroundColor Color?
The default color for the foreground of the step node. If not set, it will be read from the theme.
final
enableRippleEffect bool
Whether to enable the ripple effect.
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
The icon widget to display.
final
iconColor Color?
The color of the icon.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape StepNodeShape?
The shape of the step node.
final

Methods

copyWith({Color? defaultForegroundColor, Color? activeForegroundColor, Color? iconColor, Color? activeIconColor, StepNodeShape? shape, BoxDecoration? decoration, BoxDecoration? activeDecoration, Widget? icon, Widget? activeIcon, bool? enableRippleEffect, Duration? animationDuration, OuterBorderStyle? borderStyle}) StepNodeStyle
Creates a copy of this StepNodeStyle but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited