step_progress library
Classes
- OuterBorderStyle
- A class that defines the style for the outer border of a step progress widget.
- RippleEffectStyle
- A class that defines the style for the ripple effect in a step node.
- StepLabelStyle
- A class that defines the style for a step label in a step progress widget.
- StepLineStyle
- A class that defines the style for a step line in a step progress.
- StepNodeStyle
- A class that defines the style for a step node in a step progress indicator.
- StepProgress
- A widget that displays a step progress indicator.
- StepProgressController
- A controller class that extends ChangeNotifier to manage the state and notify listeners about changes in the step progress.
- StepProgressTheme
- A widget that provides theme data to descendant widgets.
- StepProgressThemeData
- A class that defines the theme data for the Step Progress widget.
Enums
- StepLabelAlignment
- An enumeration that defines the possible alignments for step labels in a step progress indicator.
- StepNodeShape
- An enumeration representing the different shapes that a step node can have.
- StepProgressHighlightOptions
- An enumeration that defines the available options for highlighting steps in a step progress indicator. This can be used to customize the appearance or behavior of highlighted steps.
- StepProgressVisibilityOptions
- Defines the visibility options for displaying steps in a step progress indicator.
Typedefs
- OnStepChanged = void Function(int currentIndex)
- A typedef for a callback function that is called when the step changes.
- OnStepLineTapped = void Function(int index)
- A typedef for a callback function that is triggered when a step line is tapped.
- OnStepNodeTapped = void Function(int index)
- A typedef for a callback function that is triggered when a step is tapped.
- StepLabelBuilder = Widget? Function(int index, int completedStepIndex)
- A typedef for a function that builds an optional widget to label a step in a step progress indicator.
- StepNodeIconBuilder = Widget? Function(int index, int completedStepIndex)
- A typedef for a function that builds optional widget for a step node icon.