StepNodeIconBuilder typedef
A typedef for a function that builds optional widget for a step node icon.
The function takes two parameters:
index: The index of the current step.completedStepIndex: The index of the last completed step.
Returns an optional Widget that represents the icon for the step node.
Implementation
typedef StepNodeIconBuilder = Widget? Function(
int index, int completedStepIndex);